#!/usr/bin/python3

# SPDX-FileCopyrightText: 2006-2021 Istituto Italiano di Tecnologia (IIT)
# SPDX-License-Identifier: BSD-3-Clause

import yarp
import unittest

yarp.Network.init()
yarp.Network.setLocalMode(True)


class ImageTest(unittest.TestCase):

    def test_send_and_recv_setExt(self):
        port_in = yarp.Port()
        in_port_name = '/test/img:i'
        self.assertTrue(port_in.open(in_port_name))
        port_out = yarp.Port()
        port_out.enableBackgroundWrite(True);
        out_port_name = '/test/img:o'
        self.assertTrue(port_out.open(out_port_name))
        self.assertTrue(yarp.Network.connect(port_out.getName(), port_in.getName()))
        yarp.delay(0.5)
        height = 240
        width = 320
        yarp_img_out = yarp.ImageMono()
        yarp_img_out.resize(width, height)
        yarp_img_in = yarp.ImageMono()
        self.assertEqual(240, yarp_img_out.height())
        self.assertEqual(320, yarp_img_out.width())
        yarp_vector = yarp.Vector()
        yarp_vector.resize(320*240, 0)
        self.assertTrue(240*320, yarp_vector.size())
        yarp_img_out.setExternal(yarp_vector, width, height)
        self.assertTrue(port_out.write(yarp_img_out))
        yarp.delay(0.5)
        self.assertTrue(port_in.read(yarp_img_in))
        self.assertEqual(240, yarp_img_in.height())
        self.assertEqual(320, yarp_img_in.width())

        port_out.close()
        port_in.close()


if __name__ == '__main__':
    unittest.main()



#!/usr/bin/python3

# SPDX-FileCopyrightText: 2006-2021 Istituto Italiano di Tecnologia (IIT)
# SPDX-License-Identifier: BSD-3-Clause

import yarp
import unittest

class VectorTest(unittest.TestCase):

    def test_vector_copy_costructor(self):
        vecSize = 10
        vec = yarp.Vector(vecSize)
        self.assertEqual(vec.size(), vecSize)
        vecCheck = yarp.Vector(vec)
        self.assertEqual(vec.size(), vecCheck.size())

        # Check copy constructor from a Vector
        # returned by a function
        mat = yarp.Matrix(3,3)
        mat.eye()
        vecTest = yarp.Vector(mat.getRow(0))
        self.assertEqual(vecTest.size(), 3)
        # Initializer list constructor
        vec2 = yarp.Vector([1.0, 2.0, 3.0])
        self.assertEqual(vec2.size(), 3)
        self.assertEqual(vec2.get(0), 1.0)
        self.assertEqual(vec2.get(1), 2.0)
        self.assertEqual(vec2.get(2), 3.0)


if __name__ == '__main__':
    unittest.main()



#!/usr/bin/python3

# SPDX-FileCopyrightText: 2006-2021 Istituto Italiano di Tecnologia (IIT)
# SPDX-License-Identifier: BSD-3-Clause

import argparse

def printPortTags(out_file, ports, port_type, host, additional_flags):
    for port in ports:
        # print datadumper launch
        out_file.write("\t<module>\n");
        out_file.write("\t\t<name>yarpdatadumper</name>\n");
        out_file.write("\t\t<parameters>--name /dumper"+port+" --type "+port_type+" "+additional_flags+"</parameters>\n");
        out_file.write("\t\t<node>"+host+"</node>\n");
        out_file.write("\t</module>\n");

        # print connection between datadumper and port
        out_file.write("\t<connection>\n");
        out_file.write("\t\t<from>"+port+"</from>\n");
        out_file.write("\t\t<to>/dumper"+port+"</to>\n");
        out_file.write("\t\t<protocol>udp</protocol>\n");
        out_file.write("\t</connection>\n");

def main():
    parser = argparse.ArgumentParser(description='Tool for generating a YarpManager XML application for dumping a list of YARP ports using the yarpdatadumper.')
    parser.add_argument('--ports', nargs='+', dest="ports", action='store', required=True, help='list of ports (serializable to bottles) to dump')
    parser.add_argument('--imagePorts', nargs='+', dest="imagePorts", action='store', help='list of ports (of to dump')
    parser.add_argument('--host', nargs=1,  dest="host", action='store', required=True, help='host where to launch the dataDumpers')
    parser.add_argument('--name', nargs=1,  dest="name", action='store', required=True, help='name of the application, the file will be saved as name.xml')
    parser.add_argument('--rxTime', action='store_true',help='pass --rxTime flag to the yarpdatadumpers')
    parser.add_argument('--txTime', action='store_true',help='pass --txTime flag to the yarpdatadumpers')
    parser.add_argument('--addVideo', action='store_true',help='pass --addVideo flag to the yarpdatadumpers')
    args = parser.parse_args()

    # open output file
    filename = args.name[0] + ".xml";
    out_file = open(filename,"w")

    out_file.write("<application>\n");
    out_file.write("\t<name>"+args.name[0]+"</name>\n");
    out_file.write("\t<dependencies>\n");
    for port in args.ports:
        out_file.write("\t\t<port>"+port+"</port>\n");
    out_file.write("\t</dependencies>\n");

    additional_flags = "";
    if(args.rxTime):
        additional_flags += " --rxTime";
    if(args.txTime):
        additional_flags += " --txTime";
    if(args.addVideo):
        additional_flags += " --addVideo";

    if( args.ports is not None):
        printPortTags(out_file,args.ports,"bottle",args.host[0],additional_flags);
    if( args.imagePorts is not None):
        printPortTags(out_file,args.imagePorts,"image",args.host[0],additional_flags);

    out_file.write("</application>\n");

if __name__ == "__main__":
    main()
